# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/shared/v1alpha/request_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,kaskada/shared/v1alpha/request_details.proto\x12\x16kaskada.shared.v1alpha\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestIdB\xf8\x01\n\x1a\x63om.kaskada.shared.v1alphaB\x13RequestDetailsProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\xa2\x02\x03KSX\xaa\x02\x16Kaskada.Shared.V1alpha\xca\x02\x16Kaskada\\Shared\\V1alpha\xe2\x02\"Kaskada\\Shared\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Shared::V1alphab\x06proto3')



_REQUESTDETAILS = DESCRIPTOR.message_types_by_name['RequestDetails']
RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.shared.v1alpha.request_details_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.shared.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.shared.v1alphaB\023RequestDetailsProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\242\002\003KSX\252\002\026Kaskada.Shared.V1alpha\312\002\026Kaskada\\Shared\\V1alpha\342\002\"Kaskada\\Shared\\V1alpha\\GPBMetadata\352\002\030Kaskada::Shared::V1alpha'
  _REQUESTDETAILS._serialized_start=72
  _REQUESTDETAILS._serialized_end=119
# @@protoc_insertion_point(module_scope)
