# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/shared/v1alpha/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/shared/v1alpha/catalog.proto\x12\x16kaskada.shared.v1alpha\"P\n\x06S3Path\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\x12\x16\n\x06prefix\x18\x03 \x01(\tR\x06prefix\"\xa2\x01\n\rCatalogConfig\x12@\n\x04glue\x18\x01 \x01(\x0b\x32*.kaskada.shared.v1alpha.CatalogConfig.GlueH\x00R\x04glue\x1a\x44\n\x04Glue\x12<\n\twarehouse\x18\x01 \x01(\x0b\x32\x1e.kaskada.shared.v1alpha.S3PathR\twarehouseB\t\n\x07\x63\x61talogB\xf1\x01\n\x1a\x63om.kaskada.shared.v1alphaB\x0c\x43\x61talogProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\xa2\x02\x03KSX\xaa\x02\x16Kaskada.Shared.V1alpha\xca\x02\x16Kaskada\\Shared\\V1alpha\xe2\x02\"Kaskada\\Shared\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Shared::V1alphab\x06proto3')



_S3PATH = DESCRIPTOR.message_types_by_name['S3Path']
_CATALOGCONFIG = DESCRIPTOR.message_types_by_name['CatalogConfig']
_CATALOGCONFIG_GLUE = _CATALOGCONFIG.nested_types_by_name['Glue']
S3Path = _reflection.GeneratedProtocolMessageType('S3Path', (_message.Message,), {
  'DESCRIPTOR' : _S3PATH,
  '__module__' : 'kaskada.shared.v1alpha.catalog_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.shared.v1alpha.S3Path)
  })
_sym_db.RegisterMessage(S3Path)

CatalogConfig = _reflection.GeneratedProtocolMessageType('CatalogConfig', (_message.Message,), {

  'Glue' : _reflection.GeneratedProtocolMessageType('Glue', (_message.Message,), {
    'DESCRIPTOR' : _CATALOGCONFIG_GLUE,
    '__module__' : 'kaskada.shared.v1alpha.catalog_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.shared.v1alpha.CatalogConfig.Glue)
    })
  ,
  'DESCRIPTOR' : _CATALOGCONFIG,
  '__module__' : 'kaskada.shared.v1alpha.catalog_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.shared.v1alpha.CatalogConfig)
  })
_sym_db.RegisterMessage(CatalogConfig)
_sym_db.RegisterMessage(CatalogConfig.Glue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.shared.v1alphaB\014CatalogProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\242\002\003KSX\252\002\026Kaskada.Shared.V1alpha\312\002\026Kaskada\\Shared\\V1alpha\342\002\"Kaskada\\Shared\\V1alpha\\GPBMetadata\352\002\030Kaskada::Shared::V1alpha'
  _S3PATH._serialized_start=64
  _S3PATH._serialized_end=144
  _CATALOGCONFIG._serialized_start=147
  _CATALOGCONFIG._serialized_end=309
  _CATALOGCONFIG_GLUE._serialized_start=230
  _CATALOGCONFIG_GLUE._serialized_end=298
# @@protoc_insertion_point(module_scope)
