# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ekaskada/api/v1alpha/view.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xf9\x01\n\x04View\x12\x1c\n\x07view_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x06viewId\x12$\n\tview_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\x12\'\n\nexpression\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12\x44\n\x0bresult_type\x18\x07 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeB\x03\xe0\x41\x03R\nresultType\x12>\n\x08\x61nalysis\x18\x08 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisB\x03\xe0\x41\x03R\x08\x61nalysis\"r\n\x10ListViewsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xba\x01\n\x11ListViewsResponse\x12/\n\x05views\x18\x01 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x05views\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12&\n\x0fnext_page_token\x18\x03 \x01(\tR\rnextPageToken\"6\n\x0eGetViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\"\x8e\x01\n\x0fGetViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"L\n\x11\x43reateViewRequest\x12\x37\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04view\"\xcc\x01\n\x12\x43reateViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"O\n\x11\x44\x65leteViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"b\n\x12\x44\x65leteViewResponse\x12L\n\x0frequest_details\x18\x01 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x80\x04\n\x0bViewService\x12r\n\tListViews\x12%.kaskada.api.v1alpha.ListViewsRequest\x1a&.kaskada.api.v1alpha.ListViewsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1alpha/views\x12z\n\x07GetView\x12#.kaskada.api.v1alpha.GetViewRequest\x1a$.kaskada.api.v1alpha.GetViewResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1alpha/views/{view_name=*}\x12{\n\nCreateView\x12&.kaskada.api.v1alpha.CreateViewRequest\x1a\'.kaskada.api.v1alpha.CreateViewResponse\"\x1c\x82\xd3\xe4\x93\x02\x16:\x04view\"\x0e/v1alpha/views\x12\x83\x01\n\nDeleteView\x12&.kaskada.api.v1alpha.DeleteViewRequest\x1a\'.kaskada.api.v1alpha.DeleteViewResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1alpha/views/{view_name=*}B\xd9\x01\n\x17\x63om.kaskada.api.v1alphaB\tViewProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_VIEW = DESCRIPTOR.message_types_by_name['View']
_LISTVIEWSREQUEST = DESCRIPTOR.message_types_by_name['ListViewsRequest']
_LISTVIEWSRESPONSE = DESCRIPTOR.message_types_by_name['ListViewsResponse']
_GETVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetViewRequest']
_GETVIEWRESPONSE = DESCRIPTOR.message_types_by_name['GetViewResponse']
_CREATEVIEWREQUEST = DESCRIPTOR.message_types_by_name['CreateViewRequest']
_CREATEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['CreateViewResponse']
_DELETEVIEWREQUEST = DESCRIPTOR.message_types_by_name['DeleteViewRequest']
_DELETEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DeleteViewResponse']
View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.View)
  })
_sym_db.RegisterMessage(View)

ListViewsRequest = _reflection.GeneratedProtocolMessageType('ListViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsRequest)
  })
_sym_db.RegisterMessage(ListViewsRequest)

ListViewsResponse = _reflection.GeneratedProtocolMessageType('ListViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsResponse)
  })
_sym_db.RegisterMessage(ListViewsResponse)

GetViewRequest = _reflection.GeneratedProtocolMessageType('GetViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewRequest)
  })
_sym_db.RegisterMessage(GetViewRequest)

GetViewResponse = _reflection.GeneratedProtocolMessageType('GetViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewResponse)
  })
_sym_db.RegisterMessage(GetViewResponse)

CreateViewRequest = _reflection.GeneratedProtocolMessageType('CreateViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewRequest)
  })
_sym_db.RegisterMessage(CreateViewRequest)

CreateViewResponse = _reflection.GeneratedProtocolMessageType('CreateViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewResponse)
  })
_sym_db.RegisterMessage(CreateViewResponse)

DeleteViewRequest = _reflection.GeneratedProtocolMessageType('DeleteViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewRequest)
  })
_sym_db.RegisterMessage(DeleteViewRequest)

DeleteViewResponse = _reflection.GeneratedProtocolMessageType('DeleteViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewResponse)
  })
_sym_db.RegisterMessage(DeleteViewResponse)

_VIEWSERVICE = DESCRIPTOR.services_by_name['ViewService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\tViewProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _VIEW.fields_by_name['view_id']._options = None
  _VIEW.fields_by_name['view_id']._serialized_options = b'\340A\003'
  _VIEW.fields_by_name['view_name']._options = None
  _VIEW.fields_by_name['view_name']._serialized_options = b'\372B\004r\002\020\001'
  _VIEW.fields_by_name['expression']._options = None
  _VIEW.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _VIEW.fields_by_name['result_type']._options = None
  _VIEW.fields_by_name['result_type']._serialized_options = b'\340A\003'
  _VIEW.fields_by_name['analysis']._options = None
  _VIEW.fields_by_name['analysis']._serialized_options = b'\340A\003'
  _LISTVIEWSREQUEST.fields_by_name['page_size']._options = None
  _LISTVIEWSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETVIEWREQUEST.fields_by_name['view_name']._options = None
  _GETVIEWREQUEST.fields_by_name['view_name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEVIEWREQUEST.fields_by_name['view']._options = None
  _CREATEVIEWREQUEST.fields_by_name['view']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEVIEWREQUEST.fields_by_name['view_name']._options = None
  _DELETEVIEWREQUEST.fields_by_name['view_name']._serialized_options = b'\372B\004r\002\020\001'
  _VIEWSERVICE.methods_by_name['ListViews']._options = None
  _VIEWSERVICE.methods_by_name['ListViews']._serialized_options = b'\202\323\344\223\002\020\022\016/v1alpha/views'
  _VIEWSERVICE.methods_by_name['GetView']._options = None
  _VIEWSERVICE.methods_by_name['GetView']._serialized_options = b'\202\323\344\223\002\036\022\034/v1alpha/views/{view_name=*}'
  _VIEWSERVICE.methods_by_name['CreateView']._options = None
  _VIEWSERVICE.methods_by_name['CreateView']._serialized_options = b'\202\323\344\223\002\026:\004view\"\016/v1alpha/views'
  _VIEWSERVICE.methods_by_name['DeleteView']._options = None
  _VIEWSERVICE.methods_by_name['DeleteView']._serialized_options = b'\202\323\344\223\002\036*\034/v1alpha/views/{view_name=*}'
  _VIEW._serialized_start=213
  _VIEW._serialized_end=462
  _LISTVIEWSREQUEST._serialized_start=464
  _LISTVIEWSREQUEST._serialized_end=578
  _LISTVIEWSRESPONSE._serialized_start=581
  _LISTVIEWSRESPONSE._serialized_end=767
  _GETVIEWREQUEST._serialized_start=769
  _GETVIEWREQUEST._serialized_end=823
  _GETVIEWRESPONSE._serialized_start=826
  _GETVIEWRESPONSE._serialized_end=968
  _CREATEVIEWREQUEST._serialized_start=970
  _CREATEVIEWREQUEST._serialized_end=1046
  _CREATEVIEWRESPONSE._serialized_start=1049
  _CREATEVIEWRESPONSE._serialized_end=1253
  _DELETEVIEWREQUEST._serialized_start=1255
  _DELETEVIEWREQUEST._serialized_end=1334
  _DELETEVIEWRESPONSE._serialized_start=1336
  _DELETEVIEWRESPONSE._serialized_end=1434
  _VIEWSERVICE._serialized_start=1437
  _VIEWSERVICE._serialized_end=1949
# @@protoc_insertion_point(module_scope)
