# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.api.v1alpha import view_pb2 as kaskada_dot_api_dot_v1alpha_dot_view__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fkaskada/api/v1alpha/query.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a kaskada/api/v1alpha/shared.proto\x1a\x1ekaskada/api/v1alpha/view.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\xb7\t\n\x05Query\x12\x1e\n\x08query_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07queryId\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12>\n\x07parquet\x18\x65 \x01(\x0b\x32\".kaskada.api.v1alpha.Query.ParquetH\x00R\x07parquet\x12M\n\nredis_bulk\x18\x66 \x01(\x0b\x32,.kaskada.api.v1alpha.Query.RedisBulkResponseH\x00R\tredisBulk\x12@\n\tredis_a_i\x18g \x01(\x0b\x32\".kaskada.api.v1alpha.Query.RedisAIH\x00R\x07redisAI\x12@\n\rdata_token_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x61taTokenId\x12\x34\n\x05views\x18\x04 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewB\x03\xe0\x41\x03R\x05views\x12R\n\x0fresult_behavior\x18\x05 \x01(\x0e\x32).kaskada.api.v1alpha.Query.ResultBehaviorR\x0eresultBehavior\x12\x39\n\x06limits\x18\x06 \x01(\x0b\x32!.kaskada.api.v1alpha.Query.LimitsR\x06limits\x12;\n\x05slice\x18\x07 \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x12H\n\x12\x63hanged_since_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\x12\x46\n\x11\x66inal_result_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\x12@\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x1a\t\n\x07Parquet\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a)\n\x11RedisBulkResponse\x12\x14\n\x05shape\x18\x01 \x03(\x05R\x05shape\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"\xa0\x01\n\x0eResultBehavior\x12\x1f\n\x1bRESULT_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1f\n\x1bRESULT_BEHAVIOR_ALL_RESULTS\x10\x01\x12!\n\x1dRESULT_BEHAVIOR_FINAL_RESULTS\x10\x02\x12)\n%RESULT_BEHAVIOR_FINAL_RESULTS_AT_TIME\x10\x03\x42\x12\n\x0bresponse_as\x12\x03\xf8\x42\x01\"5\n\x0fGetQueryRequest\x12\"\n\x08query_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07queryId\"I\n\x10GetQueryResponse\x12\x35\n\x05query\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.QueryB\x03\xe0\x41\x03R\x05query\"t\n\x12ListQueriesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc1\x01\n\x13ListQueriesResponse\x12\x34\n\x07queries\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.QueryR\x07queries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x8a\x02\n\x0cQueryService\x12~\n\x08GetQuery\x12$.kaskada.api.v1alpha.GetQueryRequest\x1a%.kaskada.api.v1alpha.GetQueryResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1alpha/queries/{query_id=*}\x12z\n\x0bListQueries\x12\'.kaskada.api.v1alpha.ListQueriesRequest\x1a(.kaskada.api.v1alpha.ListQueriesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1alpha/queriesB\xda\x01\n\x17\x63om.kaskada.api.v1alphaB\nQueryProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_QUERY = DESCRIPTOR.message_types_by_name['Query']
_QUERY_PARQUET = _QUERY.nested_types_by_name['Parquet']
_QUERY_LIMITS = _QUERY.nested_types_by_name['Limits']
_QUERY_REDISBULKRESPONSE = _QUERY.nested_types_by_name['RedisBulkResponse']
_QUERY_REDISAI = _QUERY.nested_types_by_name['RedisAI']
_GETQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetQueryRequest']
_GETQUERYRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResponse']
_LISTQUERIESREQUEST = DESCRIPTOR.message_types_by_name['ListQueriesRequest']
_LISTQUERIESRESPONSE = DESCRIPTOR.message_types_by_name['ListQueriesResponse']
_QUERY_RESULTBEHAVIOR = _QUERY.enum_types_by_name['ResultBehavior']
Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {

  'Parquet' : _reflection.GeneratedProtocolMessageType('Parquet', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_PARQUET,
    '__module__' : 'kaskada.api.v1alpha.query_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Query.Parquet)
    })
  ,

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_LIMITS,
    '__module__' : 'kaskada.api.v1alpha.query_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Query.Limits)
    })
  ,

  'RedisBulkResponse' : _reflection.GeneratedProtocolMessageType('RedisBulkResponse', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISBULKRESPONSE,
    '__module__' : 'kaskada.api.v1alpha.query_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Query.RedisBulkResponse)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.query_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Query.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'kaskada.api.v1alpha.query_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Query)
  })
_sym_db.RegisterMessage(Query)
_sym_db.RegisterMessage(Query.Parquet)
_sym_db.RegisterMessage(Query.Limits)
_sym_db.RegisterMessage(Query.RedisBulkResponse)
_sym_db.RegisterMessage(Query.RedisAI)

GetQueryRequest = _reflection.GeneratedProtocolMessageType('GetQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYREQUEST,
  '__module__' : 'kaskada.api.v1alpha.query_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetQueryRequest)
  })
_sym_db.RegisterMessage(GetQueryRequest)

GetQueryResponse = _reflection.GeneratedProtocolMessageType('GetQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.query_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetQueryResponse)
  })
_sym_db.RegisterMessage(GetQueryResponse)

ListQueriesRequest = _reflection.GeneratedProtocolMessageType('ListQueriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.query_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListQueriesRequest)
  })
_sym_db.RegisterMessage(ListQueriesRequest)

ListQueriesResponse = _reflection.GeneratedProtocolMessageType('ListQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.query_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListQueriesResponse)
  })
_sym_db.RegisterMessage(ListQueriesResponse)

_QUERYSERVICE = DESCRIPTOR.services_by_name['QueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\nQueryProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _QUERY_REDISAI.fields_by_name['db']._options = None
  _QUERY_REDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _QUERY_REDISAI.fields_by_name['host']._options = None
  _QUERY_REDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY_REDISAI.fields_by_name['port']._options = None
  _QUERY_REDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _QUERY.oneofs_by_name['response_as']._options = None
  _QUERY.oneofs_by_name['response_as']._serialized_options = b'\370B\001'
  _QUERY.fields_by_name['query_id']._options = None
  _QUERY.fields_by_name['query_id']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['expression']._options = None
  _QUERY.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY.fields_by_name['views']._options = None
  _QUERY.fields_by_name['views']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['create_time']._options = None
  _QUERY.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _GETQUERYREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETQUERYRESPONSE.fields_by_name['query']._options = None
  _GETQUERYRESPONSE.fields_by_name['query']._serialized_options = b'\340A\003'
  _LISTQUERIESREQUEST.fields_by_name['page_size']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _QUERYSERVICE.methods_by_name['GetQuery']._options = None
  _QUERYSERVICE.methods_by_name['GetQuery']._serialized_options = b'\202\323\344\223\002\037\022\035/v1alpha/queries/{query_id=*}'
  _QUERYSERVICE.methods_by_name['ListQueries']._options = None
  _QUERYSERVICE.methods_by_name['ListQueries']._serialized_options = b'\202\323\344\223\002\022\022\020/v1alpha/queries'
  _QUERY._serialized_start=313
  _QUERY._serialized_end=1520
  _QUERY_PARQUET._serialized_start=1140
  _QUERY_PARQUET._serialized_end=1149
  _QUERY_LIMITS._serialized_start=1151
  _QUERY_LIMITS._serialized_end=1194
  _QUERY_REDISBULKRESPONSE._serialized_start=1196
  _QUERY_REDISBULKRESPONSE._serialized_end=1237
  _QUERY_REDISAI._serialized_start=1239
  _QUERY_REDISAI._serialized_end=1337
  _QUERY_RESULTBEHAVIOR._serialized_start=1340
  _QUERY_RESULTBEHAVIOR._serialized_end=1500
  _GETQUERYREQUEST._serialized_start=1522
  _GETQUERYREQUEST._serialized_end=1575
  _GETQUERYRESPONSE._serialized_start=1577
  _GETQUERYRESPONSE._serialized_end=1650
  _LISTQUERIESREQUEST._serialized_start=1652
  _LISTQUERIESREQUEST._serialized_end=1768
  _LISTQUERIESRESPONSE._serialized_start=1771
  _LISTQUERIESRESPONSE._serialized_end=1964
  _QUERYSERVICE._serialized_start=1967
  _QUERYSERVICE._serialized_end=2233
# @@protoc_insertion_point(module_scope)
