# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.puffin.v1alpha import iceberg_table_pb2 as kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2


class TableServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTables = channel.unary_unary(
                '/kaskada.puffin.v1alpha.TableService/ListTables',
                request_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesRequest.SerializeToString,
                response_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesResponse.FromString,
                )
        self.GetTable = channel.unary_unary(
                '/kaskada.puffin.v1alpha.TableService/GetTable',
                request_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableRequest.SerializeToString,
                response_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableResponse.FromString,
                )
        self.GetTableFiles = channel.unary_unary(
                '/kaskada.puffin.v1alpha.TableService/GetTableFiles',
                request_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesRequest.SerializeToString,
                response_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesResponse.FromString,
                )


class TableServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTableFiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TableServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTables': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTables,
                    request_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesRequest.FromString,
                    response_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesResponse.SerializeToString,
            ),
            'GetTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTable,
                    request_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableRequest.FromString,
                    response_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableResponse.SerializeToString,
            ),
            'GetTableFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTableFiles,
                    request_deserializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesRequest.FromString,
                    response_serializer=kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.puffin.v1alpha.TableService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TableService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.puffin.v1alpha.TableService/ListTables',
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesRequest.SerializeToString,
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.ListTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.puffin.v1alpha.TableService/GetTable',
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableRequest.SerializeToString,
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTableFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.puffin.v1alpha.TableService/GetTableFiles',
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesRequest.SerializeToString,
            kaskada_dot_puffin_dot_v1alpha_dot_iceberg__table__pb2.GetTableFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
